# -*- coding: utf-8 -*-

"""Constants used by parsers/subparsers alike"""

_VERBOSE = """Be verbose in how odds/simulations are calculated."""
_GEN = """The generation game to simulate"""


def get_argument_groups(p, cmd):
    """Get the common required and optional arguments groups"""
    required_args = p.add_argument_group(f"{cmd} required")
    required_args.add_argument(
        "-g", "--gen",
        dest="gen",
        type=int,  # TODO: if roman in future, change to str
        help="The generation",
    )

    optional_args = p.add_argument_group(f"{cmd} optional")
    optional_args.add_argument(
        "--verbose",
        action="store_true",
        help=_VERBOSE,
    )

    optional_args.add_argument(
        "-s", "--swarm_size",
        dest="swarm_size",
        type=int,
        help="The size of the pokemon swarm, or candidate 'mons. For instance,"
             "if the swarm size is 5, will compute the likelihood or number "
             "of required resets until AT LEAST ONE of the swarm is shiny. If "
             "not provided, will default to 1",
    )

    optional_args.add_argument(
        "--charm",
        action="store_true",
        help="Whether the shiny charm is equipped. This is only applicable in "
             "gen 5+",
    )

    p.set_defaults(
        swarm_size=1,
        charm=False,
        verbose=False,
    )

    return required_args, optional_args


def get_logging_level(args, default="INFO"):
    """Get the logging level from the CLI args"""
    verbose = args.verbose
    if verbose:
        return "DEBUG"
    return default


def parse_generation(args):
    """Parse the `generation` arg or raise an error"""
    gen = args.gen
    if not gen:
        raise ValueError(
            "Generation is required! Please pass the generation "
            "using the --gen argument"
        )
    return gen



# -*- coding: utf-8 -*-

from pathlib import Path

try:
    version_path = Path(__file__).parent / 'VERSION'
    version = version_path.read_text().strip()
except FileNotFoundError:
    version = '0.0.0'

__version__ = version
del version



# -*- coding: utf-8 -*-

from pathlib import Path
from setuptools import setup
from setuptools import find_packages

# Minimum allowed version
MIN_PYTHON = (3, 7)

# Get package version
package_name = "giovanni"
try:
    version_path = Path(__file__).parent / package_name / 'VERSION'
    package_version = version_path.read_text().strip()
except FileNotFoundError:
    package_version = '0.0.0'

with open('requirements.txt', 'r') as req:
    req_file = [line for line in req.read().split() if line]

print("Requirements:\n" + '\n'.join(req_file))

with open("README.md", encoding="utf-8") as readme:
    LONG_DESCRIPTION = readme.read()

# setup library
setup(
    name=package_name,
    version=package_version,
    description="Simulate the odds/time required to SR for a shiny",
    long_description=LONG_DESCRIPTION,
    author="Taylor Smith",
    project_urls={
        'Source Code': f'https://github.com/tgsmith61591/{package_name}',
    },
    author_email="taylor.smith@alkaline-ml.com",
    classifiers=[
        'Intended Audience :: Developers',
        'Programming Language :: Python',
        'Topic :: Software Development',
        'Programming Language :: Python :: 3.7',
    ],
    packages=find_packages(),
    include_package_data=True,
    zip_safe=False,
    install_requires=req_file,
    python_requires=f'>={MIN_PYTHON[0]}.{MIN_PYTHON[1]}',
)
